// Copyright (c) 2002, Peter Bentley
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
//   Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
// 
//   Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
//   The name Peter Bentley may not be used to endorse or promote
// products derived from this software without specific prior
// written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// $Id: OmdTocCtlr.h,v 1.12 2002/11/24 17:07:30 pete Exp $


#import <Cocoa/Cocoa.h>

@class OmdUnit;
@class OmdToc;


// Constants for the node types we allow in the outline view
extern NSString *kOmdTitleNode;
extern NSString *kOmdGroupNode;
extern NSString *kOmdTrackNode;

@interface OmdTocCtlr : NSObject {
    IBOutlet NSOutlineView	*outline;
    IBOutlet OmdUnit		*omdUnit;

    OmdToc			*toc;
    NSString			*currTitle;
    
    NSMutableArray		*children;
    
    BOOL			expanded;
}

- (void) refresh;
- (void) updateView;

- (void) findChildren;

- (void) saveCurrentTitle: (NSString *) newTitle;


// Outline view data

- (int) numberOfChildren;
- (id) childAtIndex: (int) index;

- (int) id;
- (NSString *) idString;
- (NSString *) groupString;
- (NSString *) titleString;
- (void) setTitleString: (NSString *) str;
- (NSString *) lengthString;
- (NSString *) codecString;
- (NSString *) rateString;
- (NSString *) lockedString;
- (NSString *) nodeType;

- (NSMutableArray *) outlineTargets;

- (IBAction) test: (id) sender;
- (IBAction) createGroup: (id) sender;
- (IBAction) deleteThings: (id) sender;

- (BOOL) validateMenuItem: (id <NSMenuItem>) menuItem;


@end
